Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5896)

Unified Diff: chrome/browser/supervised_user/supervised_user_navigation_observer.cc

Issue 2345053006: Remove IsSynchronous API from NavigationHandle. (Closed)
Patch Set: Addressed review comments. Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/supervised_user/supervised_user_navigation_observer.cc
diff --git a/chrome/browser/supervised_user/supervised_user_navigation_observer.cc b/chrome/browser/supervised_user/supervised_user_navigation_observer.cc
index 90edc77c43c00592d65b5cd01c3b9675b3f0dc36..6bf7795a141654f922327269845a380450ec7976 100644
--- a/chrome/browser/supervised_user/supervised_user_navigation_observer.cc
+++ b/chrome/browser/supervised_user/supervised_user_navigation_observer.cc
@@ -66,9 +66,9 @@ void SupervisedUserNavigationObserver::OnRequestBlocked(
void SupervisedUserNavigationObserver::DidFinishNavigation(
content::NavigationHandle* navigation_handle) {
// Only filter synchronous navigations (eg. pushState/popState); others will
// have been filtered by the ResourceThrottle.
- if (!navigation_handle->IsSynchronousNavigation())
+ if (!navigation_handle->IsSamePage())
return;
if (!navigation_handle->IsInMainFrame())
« no previous file with comments | « chrome/browser/ssl/chrome_security_state_model_client.cc ('k') | content/browser/frame_host/navigation_handle_impl.h » ('j') | no next file with comments »
@@ -66,9 +66,9 @@ void SupervisedUserNavigationObserver::OnRequestBlocked(
void SupervisedUserNavigationObserver::DidFinishNavigation(
content::NavigationHandle* navigation_handle) {
- // Only filter synchronous navigations (eg. pushState/popState); others will
+ // Only filter same page navigations (eg. pushState/popState); others will
// have been filtered by the ResourceThrottle.

Powered by Google App Engine
This is Rietveld 408576698